<?php
namespace Gath\Product;

use Webshop\Product\ProductGatewayInterface;
use Zend\Hydrator\HydratorProviderInterface;

/**
 * Class ConfigProvider
 *
 * @package Gath\Product
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/gath-product
 */
final class ConfigProvider implements HydratorProviderInterface
{
    /**
     * @return array
     */
    public function __invoke(): array
    {
        return [
            'dependencies' => $this->getDependencies(),
            'hydrators' => $this->getHydratorConfig(),
            'gath' => [
                'endpoints' => $this->getGathEndpoints(),
            ],
        ];
    }

    public function getGathEndpoints(): array
    {
        return [
            'products.byid' => [
                'path' => '/product/byids',
                'method' => 'POST',
                'result_class' => Product::class,
            ],
        ];
    }

    /**
     * @return array
     */
    public function getDependencies(): array
    {
        return [
            'factories' => [
                ProductGatewayInterface::class => ProductGatewayFactory::class,
            ],
        ];
    }

    /**
     * Provide plugin manager configuration for hydrators.
     *
     * @see    https://docs.zendframework.com/zend-expressive/v3/features/container/config/#the-format
     * @return mixed[][]
     */
    public function getHydratorConfig(): array
    {
        return [
            'aliases' => [
                Product::class => Hydrator\ProductHydrator::class,
            ],

            'invokables' => [
                Hydrator\ProductHydrator::class,
            ],
        ];
    }
}