<?php
namespace Gath\Product;

use Gath\ClientInterface;
use Gath\Product\Hydrator\Strategy\ProductIdStrategy;
use Webshop\Product\ProductGatewayInterface;
use Webshop\Product\ProductInterface;

/**
 * Class ProductGateway
 *
 * @package Gath\Product
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/gath-product
 */
final class ProductGateway implements ProductGatewayInterface
{
    /** @var ClientInterface */
    private $gath;

    /**
     * ProductGateway constructor.
     * @param ClientInterface $gath
     */
    public function __construct(ClientInterface $gath)
    {
        $this->gath = $gath;
    }

    /**
     * @param int $id
     * @return ProductInterface
     */
    public function find(int $id): ?ProductInterface
    {
        $products = $this->findByIds([$id]);
        return $products[0] ?? null;
    }

    /**
     * @param array $ids
     * @return ProductInterface[]
     */
    public function findByIds(array $ids): array
    {
        $strategy = new ProductIdStrategy();
        $params = [];
        $typeMap = [
            'simple' => 'SimpleIds',
            'grouped' => 'GroupedIds',
            'variable' => 'VariableIds',
            'tire' => 'TireIds',
        ];

        foreach ($ids as $id) {
            $id = $strategy->extract($id);
            $type = $id['type'] ?? false;

            if (!$type) {
                continue;
            }

            if (!isset($params[$typeMap[$id['type']]])) {
                $params[$typeMap[$id['type']]] = [];
            }

            $params[$typeMap[$id['type']]][] = $id['data_link'];
        }

        if (empty($params)) return [];

        $result = $this->gath->query('products.byid', $params);
        return $result->getResults();
    }
}